<a name="aea.helpers.search.generic"></a>
# aea.helpers.search.generic

This module contains a generic data model.

<a name="aea.helpers.search.generic.GenericDataModel"></a>
## GenericDataModel Objects

```python
class GenericDataModel(DataModel)
```

Generic data model.

<a name="aea.helpers.search.generic.GenericDataModel.__init__"></a>
#### `__`init`__`

```python
 | __init__(data_model_name: str, data_model_attributes: Dict[str, Any])
```

Initialise the dataModel.

